//TIMER click on socket 1

#include "timer_hw.h"
#include <built_in.h>
//#define CountFromZero

void Auxiliary_Code(void);
void Set_Index(unsigned short index);
void Write_Command(unsigned short cmd);
void Write_Data(unsigned int _data);

// TFT module connections
char TFT_DataPort at GPIO_PORT_32_39;
sbit TFT_RST at GPIO_PIN42_bit;
sbit TFT_RS at GPIO_PIN40_bit;
sbit TFT_CS at GPIO_PIN41_bit;
sbit TFT_RD at GPIO_PIN46_bit;
sbit TFT_WR at GPIO_PIN47_bit;
sbit TFT_BLED at GPIO_PIN58_bit;
// End TFT module connections

void Auxiliary_Code() {
  TFT_WR = 0;
  asm nop;
  TFT_WR = 1;
}

void Set_Index(unsigned short index) {
  TFT_RS = 0;
  asm nop;
  TFT_DataPort = index;
  asm nop; asm nop;
  Auxiliary_Code();
}

void Write_Command(unsigned short cmd) {
  TFT_RS = 1;
  asm nop;
  TFT_DataPort = cmd;
  asm nop; asm nop;
  Auxiliary_Code();
}

void Write_Data(unsigned int _data) {
  TFT_RS = 1;
  asm nop;
  TFT_DataPort = Hi(_data);
  asm nop; asm nop;
  Auxiliary_Code();
  asm nop;
  TFT_DataPort = Lo(_data);
  asm nop; asm nop;
  Auxiliary_Code();
}

sbit TIMER_EVT at GPIO_PIN1_bit;
sbit TIMER_ALM at GPIO_PIN3_bit;

char text[24];
unsigned long ETC;              //elapsed time counter
unsigned int EC;



void Display_Init(){
  TFT_Set_Active(Set_Index, Write_Command, Write_Data);
  TFT_Init_ILI9341_8bit(320, 240);
  TFT_BLED = 1;
  TFT_Set_Pen(CL_AQUA, 1);
  TFT_Fill_Screen(CL_AQUA);
  TFT_Set_Font(TFT_defaultFont, CL_BLACK, FO_HORIZONTAL);
  TFT_Set_Pen(CL_AQUA, 1);

  TFT_Set_Brush(1, CL_AQUA, 0, LEFT_TO_RIGHT, CL_AQUA, CL_AQUA);

  TFT_Write_Text("Event count: ",10,10);
  TFT_Write_Text("Time count: ",10,50);
}

void MCU_Init() {
  GPIO_Digital_Output(&GPIO_PORT_00_07,_GPIO_PINMASK_1);
  GPIO_Digital_Input(&GPIO_PORT_00_07, _GPIO_PINMASK_0 | _GPIO_PINMASK_3);

  TIMER_EVT = 1;
  I2CM1_Init(_I2CM_SPEED_MODE_STANDARD, _I2CM_SWAP_DISABLE);
  delay_ms(200);
}

void main() {
  MCU_Init();
  timer_hal_init(DS1682_I2C_Adr);
  Display_Init();
  #ifdef CountFromZero
  timer_set_ec_value(0);
  timer_set_etc_value(0);
  TIMER_EVT = 0;
  delay_ms(100);
  TIMER_EVT = 1;
  delay_ms(100);
  #endif
  while(1) {
    delay_ms(2000);
    TFT_Rectangle(100,10,200,40);
    TFT_Rectangle(80,50,200,80);
    //Event counter
    EC = timer_get_ec_Value();
    WordToStr(EC,text);
    TFT_Write_Text(text,100,10);
    ETC = timer_get_etc_value();
    LongWordToStr(ETC,text);
    TFT_Write_Text(text,100,50);
  }

}