#ifndef TIMER_HAL_H_
#define TIMER_HAL_H_
/******************************************************************************
* Includes
*******************************************************************************/
#include "stdint.h"
/******************************************************************************
* Preprocessor Constants
*******************************************************************************/
#define STM32
//#define LM
//#define TM

//#define ATMEGA
//#define ATXMEGA
/******************************************************************************
* Configuration Constants
*******************************************************************************/
/**
 * Register address size */
#define COMMAND_SIZE            1
/**
 * Maximum buffer size */
#define MAX_BUFF_SIZE           256
/******************************************************************************
* Macros
*******************************************************************************/

/******************************************************************************
* Typedefs
*******************************************************************************/

/******************************************************************************
* Variables
*******************************************************************************/
#define DS1682_REG_CONFIG               0x00
#define DS1682_REG_ALARM                0x01
#define DS1682_REG_ELAPSED              0x05
#define DS1682_REG_EVT_CNTR             0x09
#define DS1682_REG_EEPROM               0x0B
#define DS1682_REG_RESET                0x1D
#define DS1682_REG_WRITE_DISABLE        0x1E
#define DS1682_REG_WRITE_MEM_DISABLE    0x1F

#define ECMSB_Bit                       0x01
#define AP_Bit                          0x02
#define RE_Bit                          0x04
#define AOS_Bit                         0x08
#define WMDF_Bit                        0x10
#define WDF_Bit                         0x20
#define AF_Bit                          0x40

#define DS1682_EEPROM_SIZE                10
#define DS1682_I2C_Adr                  0x6B
/******************************************************************************
* Function Prototypes
*******************************************************************************/
#ifdef __cplusplus
extern "C"{
#endif

/**
 * @brief <h3>HAL Initialization</h3>
 *
 * @par
 * Initialization of HAL layer used to initialize I2C connection and pins needed
 * for proper usage of click board.
 *
 * @param[in] address_id - hardware address
 */
void timer_hal_init( uint8_t address_id );

/**
 * @brief <h3>HAL Write</h3>
 *
 * @par
 * Generic write function adapted for SHT click.
 *
 * @param[in] command - register address
 * @param[in] buffer - data buffer
 * @param[in] count - data size in bytes
 */
void timer_hal_write( uint8_t *command,
                    uint8_t *buffer,
                    uint8_t count );

/**
 * @brief <h3>HAL Read</h3>
 *
 * @par
 * Generic read function adapted for SHT click.
 *
 * @param[in] command - register address
 * @param[out] buffer - data buffer
 * @param[in] count - data size in bytes
 */
void timer_hal_read( uint8_t *command,
                   uint8_t *buffer,
                   uint8_t count );

#ifdef __cplusplus
} // extern "C"
#endif

#endif

/*** End of File **************************************************************/