#include <stdint.h>
#include "timer_hal.h"
#include "timer_hw.h"

#define HIGH 1
#define LOW 0

void timer_read_eeprom(uint8_t* buffer, uint8_t count)
{
  uint8_t* tmp_ptr = buffer;
  uint8_t tmp_adr = DS1682_REG_EEPROM;
  timer_hal_read(&tmp_adr,tmp_ptr,count);
}

void timer_write_eeprom(uint8_t* buffer, uint8_t count)
{
  uint8_t* tmp_ptr = buffer;
  uint8_t tmp_adr = DS1682_REG_EEPROM;
  timer_hal_write(&tmp_adr, tmp_ptr, count);
}

uint32_t timer_get_etc_value()
{
    uint8_t tmp_buffer[4];
    uint8_t temp_addr = DS1682_REG_ELAPSED;
    timer_hal_read(&temp_addr,tmp_buffer,4);
    return (tmp_buffer[3] << 24) + (tmp_buffer[2] << 16) + (tmp_buffer[1] << 8) + tmp_buffer[0];

}

void timer_set_etc_value(uint32_t _value)
{
  char value_data[4];
  uint8_t tmp_adr =DS1682_REG_ELAPSED;
  value_data[0] = (char) _value;
  value_data[1] = (char) (_value >> 8);
  value_data[2] = (char) (_value >> 16);
  value_data[3] = (char) (_value >> 24);

  timer_hal_write(&tmp_adr,value_data, 4);
}

uint16_t timer_get_ec_value()
{
  uint8_t tmp[2];
  uint8_t tmp_adr = DS1682_REG_EVT_CNTR;
  timer_hal_read(&tmp_adr,tmp,2);
  return ((uint16_t) tmp[1] << 8) + (uint16_t)tmp[0];
}

void timer_set_ec_value (uint16_t _value)
{
  char value_data[2];
  uint8_t tmp_adr = DS1682_REG_EVT_CNTR;
  value_data[0] = (char) _value;
  value_data[1] = (char) (_value >> 8);

  timer_hal_write(&tmp_adr, value_data, 2);
}

uint16_t timer_timer_get_alarm_value()
{
  uint8_t tmp_adr = DS1682_REG_ALARM;
  uint8_t tmp[2];
  timer_hal_read(&tmp_adr, 2, tmp);

  return ((uint16_t)tmp[1] << 8) + (uint16_t)tmp[0];
}

/*******************************************************************************
* value unit in quarter second
* Warning!!!: When the alarm is activated, the Alarm Flag (AF)
* cannot be reset.
* Function timer_reset_device() can reset it only once!!!
* The alarm flag is set to a 1 when the ETC value matches the alarm register.
* Once the AF bit is set to a 1, it cannot be reset to  0. This bit is read-only.
*******************************************************************************/
void timer_set_alarm_value(uint32_t _value)
{
  char value_data[4];
  uint8_t tmp_adr = DS1682_REG_ALARM;
  value_data[0] = (uint8_t) _value;
  value_data[1] = (uint8_t) (_value >> 8);
  value_data[2] = (uint8_t) (_value >> 16);
  value_data[3] = (uint8_t) (_value >> 24);

  timer_hal_write(&tmp_adr, value_data, 4);
}

/*******************************************************************************
* Write Disable Flag (WDF).
* When the write disable command is written to AAh twice at memory location 1Eh,
* the WDF is set to a 1 and cannot be cleared or reset. When WDF is set to a 1,
* the alarm, ETC, and event counter registers are read-only.
* This bit is read-only.
*******************************************************************************/
void timer_set_write_disable() {
  uint8_t temp = 0xAA;
  uint8_t tmp_adr = DS1682_REG_WRITE_DISABLE;

  timer_hal_write(&tmp_adr, &temp, 1);
  timer_hal_write(&tmp_adr, &temp, 1);
}

/*******************************************************************************
* Write-Memory-Disable Flag (WMDF).
* When the write-memory-disable command is written to F0h twice at memory
* location 1Fh, the WMDF is set to a 1 and cannot be reset or cleared.
* Once the WMDF is set to a 1, the 10-byte user memory becomes read-only.
* This bit is read-only.
*******************************************************************************/
void timer_set_write_memory_disable()
{
  uint8_t temp = 0xF0;
  uint8_t tmp_adr = DS1682_REG_WRITE_MEM_DISABLE;

  timer_hal_write(&tmp_adr, &temp, 1);
  timer_hal_write(&tmp_adr, &temp, 1);
}

int8_t alarm_output_select(uint8_t select)
{
   uint8_t temp;
   uint8_t tmp_adr = DS1682_REG_CONFIG;
   timer_hal_read(&tmp_adr,&temp, 1);

   if (select == 0)
      temp &= ~(1<<3);

   else if (select == 1)
      temp |= (1<<3);

   else return -1;

   timer_hal_write(&tmp_adr,&temp, 1);
   return 0;
}

void reset_enable(bool enable)
{
   uint8_t temp;
   uint8_t tmp_adr = DS1682_REG_CONFIG;
   timer_hal_read(&tmp_adr,&temp, 1);

   if (enable == true)
      temp |= (1<<2);

   else
      temp &= ~(1<<2);

   timer_hal_write(&tmp_adr,&temp, 1);
}

int8_t  set_alarm_polarity(uint8_t polarity)
{
   uint8_t temp;
   uint8_t tmp_adr = DS1682_REG_CONFIG;
   timer_hal_read(&tmp_adr,&temp, 1);

   if (polarity == HIGH)
      temp |= 1;

   else if (polarity == LOW)
      temp &= ~(1);

   else return -1;

   timer_hal_write(&tmp_adr,&temp, 1);
   return 0;
}

//Reset command clears the ETC, EEPROM, and event counter.
//This command can be used only once!!! After that, the Configuration register will be read-only, and additional resets are ignored
void timer_reset_device()
{
  uint8_t temp = 0x55;
  uint8_t tmp_adr = DS1682_REG_RESET;
  reset_enable(true);

  timer_hal_write(&tmp_adr, &temp,1);
  timer_hal_write(&tmp_adr, &temp,1);
}