#include "timer_hal.h"
#include <stdbool.h>

void timer_read_eeprom(uint8_t* buffer, uint8_t count);

void timer_write_eeprom(uint8_t* buffer, uint8_t count);

uint32_t timer_get_etc_value();

void timer_set_etc_value(uint32_t _value);

uint16_t timer_get_ec_value();

void timer_set_ec_value(uint16_t _value);

uint16_t timer_get_alarm_value();

/*******************************************************************************
* value unit in quarter second
* Warning!!!: When the alarm is activated, the Alarm Flag (AF)
* cannot be reset.
* Function timer_reset_device() can reset it only once!!!
* The alarm flag is set to a 1 when the ETC value matches the alarm register.
* Once the AF bit is set to a 1, it cannot be reset to  0. This bit is read-only.
*******************************************************************************/
void set_alarm_value(uint32_t _value);

/*******************************************************************************
* Write Disable Flag (WDF).
* When the write disable command is written to AAh twice at memory location 1Eh,
* the WDF is set to a 1 and cannot be cleared or reset. When WDF is set to a 1,
* the alarm, ETC, and event counter registers are read-only.
* This bit is read-only.
*******************************************************************************/
void timer_set_write_disable();

/*******************************************************************************
* Write-Memory-Disable Flag (WMDF).
* When the write-memory-disable command is written to F0h twice at memory
* location 1Fh, the WMDF is set to a 1 and cannot be reset or cleared.
* Once the WMDF is set to a 1, the 10-byte user memory becomes read-only.
* This bit is read-only.
*******************************************************************************/
void timer_set_write_memory_disable();


int8_t alarm_output_select(uint8_t select);

void reset_enable(bool enable);

int8_t  set_alarm_polarity(uint8_t polarity);

//Reset command clears the ETC, EEPROM, and event counter.
//This command can be use only once!!! After that, the Configuration register will be read-only, and additional resets are ignored
void timer_reset_device();